local LibButtonFacade = LibStub("LibButtonFacade", true)
local PoisonerEnabled = IsAddOnLoaded("Poisoner")
--if not LibButtonFacade or not PoisonerEnabled then return end

function Poisoner_ButtonFacade_OnLoad(self)
	self:RegisterEvent("ADDON_LOADED")
	self:RegisterEvent("VARIABLES_LOADED")
	self:RegisterEvent("PLAYER_ENTERING_WORLD")
end

function Poisoner_ButtonFacade_OnEvent(self,event)
	if event == "VARIABLES_LOADED" or event == "ADDON_LOADED" then
		if Poisoner_ButtonFacade == nil  then
			Poisoner_ButtonFacade_LoadDefault()
		end
		Poisoner_ButtonFacade_CheckSavedVariables()
	elseif event == "PLAYER_ENTERING_WORLD" then
		if LibButtonFacade and PoisonerEnabled then
			Poisoner_ButtonFacade_Init()
			PoisonerBF_Initiated = true
			--print("|cff00ff00Poisoner|r_|cff808080ButtonFacade|r loaded.")
		else
			print("|cff00ff00Poisoner|r_|cff808080ButtonFacade|r could NOT be loaded because ButtonFacade is not loaded/installed.")
		end
	end
end

function Poisoner_ButtonFacade_LoadDefault()
	Poisoner_ButtonFacade = {}
	Poisoner_ButtonFacade["Menu Buttons"] = {}
	Poisoner_ButtonFacade["Menu Buttons"]["SkinID"] = "Blizzard"
	Poisoner_ButtonFacade["QuickButton"] = {}
	Poisoner_ButtonFacade["QuickButton"]["SkinID"] = "Blizzard"
end

function Poisoner_ButtonFacade_CheckSavedVariables()
	if not Poisoner_ButtonFacade["Menu Buttons"] then
		Poisoner_ButtonFacade["Menu Buttons"] = {}
	end
	if not Poisoner_ButtonFacade["Menu Buttons"]["SkinID"] then
		Poisoner_ButtonFacade["Menu Buttons"]["SkinID"] = "Blizzard"
	end
	if not Poisoner_ButtonFacade["QuickButton"] then
		Poisoner_ButtonFacade["QuickButton"] = {}
	end
	if not Poisoner_ButtonFacade["QuickButton"]["SkinID"] then
		Poisoner_ButtonFacade["QuickButton"]["SkinID"] = "Blizzard"
	end
end

function Poisoner_ButtonFacade_FindPoisons()
	local i, itemLink, bagSlots, bagId, icon, quantity;
	local ret = {};
	for i=0, 4 do
		itemLink = nil;
		bagSlots = GetContainerNumSlots(i);
		if (bagSlots > 0) then
			for j=1, bagSlots do
				itemLink = nil;
				itemLink = GetContainerItemLink(i, j);
				icon, quantity = GetContainerItemInfo(i, j)
				if (itemLink) then
					local itemId = nil;
					local itemName = nil;
					local itemRank = nil;
					local idx,pattern;
					for idx, pattern in ipairs(Poisoner_Patterns) do
						_, _, itemId, itemName, itemRank = string.find(itemLink, "item:(%d+).*%[("..pattern..")%]");
						if (itemName ~= nil) then
							break;
						end
					end
					
					if (itemName ~= nil) then
						-- if the quantity is 1, we either have a single consumable item, or an expendable item
						if (quantity == 1) then
							local charges = Poisoner_CountCharges(i, j);
							if (charges ~= nil) then
								quantity = charges;
							end
						end

						local t = ret[itemName];
						if (t == nil) then
							t = { name=itemName, icon=icon, quantity=0, rank=itemRank, id=itemId, bag=i, bagslot=j };
							ret[itemName] = t;
						end
						t.quantity = t.quantity + quantity;
						Poisoner_PoisonsEverSeen[itemName] = icon;
					end
				end
			end
		end
	end
	-- include zero counts for previously seen items we no longer have
	for prevItemName, prevIcon in pairs(Poisoner_PoisonsEverSeen) do
		local t = ret[prevItemName];
		if (t == nil) then
			t = { name=prevItemName, icon=prevIcon, quantity=0, bag=-1, bagslot=-1 };
			ret[prevItemName] = t;
		end
	end
	return ret;
end


function Poisoner_ButtonFacade_Init()
	LibButtonFacade:Group("Poisoner", "Menu Buttons"):Skin(Poisoner_ButtonFacade["Menu Buttons"]["SkinID"])
	LibButtonFacade:Group("Poisoner", "QuickButton"):Skin(Poisoner_ButtonFacade["QuickButton"]["SkinID"])

    for _, t in pairs(Poisoner_ButtonFacade_FindPoisons()) do
		local tname = string.gsub(t.name, " ", "_");
		LibButtonFacade:Group("Poisoner", "Menu Buttons"):AddButton(_G["PoisonerMenuButton__"..tname])
    end
	
	if POISONER_CONFIG then
		if POISONER_CONFIG.Poisons then
			for _, v in pairs(POISONER_CONFIG.Poisons) do
				if v ~= 0 then
					local name = string.gsub(v, " ", "_");
					LibButtonFacade:Group("Poisoner", "Menu Buttons"):AddButton(_G["PoisonerMenuButton__"..name])
				end
			end
		end
	end
	
	LibButtonFacade:Group("Poisoner", "QuickButton"):AddButton(_G["Poisoner_QuickButton"])
--	LibStub("LibButtonFacade", true):Group("TrinketMenuBF", "QuickButton"):AddButton(_G["Poisoner_QuickButton"])
	
	local function Poisoner_ButtonFacade_SkinCallback(arg, SkinID, Gloss, Backdrop, Group, Button, Colors, ...)
		if not Group then
			Poisoner_ButtonFacade.SkinID = SkinID
			Poisoner_ButtonFacade.Gloss = Gloss
			Poisoner_ButtonFacade.Backdrop = Backdrop
			Poisoner_ButtonFacade.Colors = Colors
		else
			Poisoner_ButtonFacade[Group]["SkinID"] = SkinID
			Poisoner_ButtonFacade[Group]["Gloss"] = Gloss
			Poisoner_ButtonFacade[Group]["Backdrop"] = Backdrop
			Poisoner_ButtonFacade[Group]["Colors"] = Colors
		end
		if Poisoner_ButtonFacade["Menu Buttons"]["SkinID"] == "Blizzard" then
			for _, t in pairs(Poisoner_ButtonFacade_FindPoisons()) do
				local tname = string.gsub(t.name, " ", "_");
				local buttonName = "PoisonerMenuButton"..tname;
				local button = _G[buttonName];
				if (button ~= nil) then
					_G[buttonName.."Icon"]:ClearAllPoints()
					_G[buttonName.."Icon"]:SetPoint("CENTER",button,"CENTER",-0.5,-0.5)
				end
			end
		end
		if Poisoner_ButtonFacade["QuickButton"]["SkinID"] == "Blizzard" then
			Poisoner_QuickButtonIcon:ClearAllPoints()
			Poisoner_QuickButtonIcon:SetPoint("CENTER",Poisoner_QuickButton,"CENTER",-0.5,-0.5)
		end
	end
	
	LibButtonFacade:RegisterSkinCallback("Poisoner", Poisoner_ButtonFacade_SkinCallback, self)
	
	if Poisoner_ButtonFacade["Menu Buttons"]["SkinID"] == "Blizzard" then
		for _, t in pairs(Poisoner_ButtonFacade_FindPoisons()) do
			local tname = string.gsub(t.name, " ", "_");
			local buttonName = "PoisonerMenuButton"..tname;
			local button = _G[buttonName];
			if (button ~= nil) then
				_G[buttonName.."Icon"]:ClearAllPoints()
				_G[buttonName.."Icon"]:SetPoint("CENTER",button,"CENTER",-0.5,-0.5)
			end
		end
	end
	if Poisoner_ButtonFacade["QuickButton"]["SkinID"] == "Blizzard" then
		Poisoner_QuickButtonIcon:ClearAllPoints()
		Poisoner_QuickButtonIcon:SetPoint("CENTER",Poisoner_QuickButton,"CENTER",-0.5,-0.5)
	end
	
end

